# Generated by Django 5.2 on 2024-08-09 10:13

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bionty", "0035_alter_protein_gene_symbol"),
    ]

    operations = [
        migrations.AlterField(
            model_name="source",
            name="artifacts",
            field=models.ManyToManyField(
                related_name="_source_artifact_of", to="lamindb.artifact"
            ),
        ),
        migrations.AlterField(
            model_name="source",
            name="dataframe_artifact",
            field=models.ForeignKey(
                default=None,
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                related_name="_source_dataframe_of",
                to="lamindb.artifact",
            ),
        ),
    ]
