# Generated by Django 5.2 on 2025-01-07 14:37

import django.db.models.deletion
import lamindb.base.fields
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("bionty", "0041_alter_artifactcellline_artifact_and_more"),
        ("lamindb", "0071_lamindbv1_migrate_schema"),
    ]

    operations = [
        migrations.AddField(
            model_name="cellline",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="cellmarker",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="celltype",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="developmentalstage",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="disease",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="ethnicity",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="experimentalfactor",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="gene",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="organism",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="pathway",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="phenotype",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="protein",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="source",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="tissue",
            name="_branch_code",
            field=models.SmallIntegerField(db_index=True, default=1, db_default=1),
        ),
        migrations.AddField(
            model_name="cellline",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.AddField(
            model_name="cellmarker",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.AddField(
            model_name="celltype",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.AddField(
            model_name="developmentalstage",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.AddField(
            model_name="disease",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.AddField(
            model_name="ethnicity",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.AddField(
            model_name="experimentalfactor",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.AddField(
            model_name="gene",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.AddField(
            model_name="organism",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.AddField(
            model_name="pathway",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.AddField(
            model_name="phenotype",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.AddField(
            model_name="protein",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.AddField(
            model_name="source",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.AddField(
            model_name="tissue",
            name="aux",
            field=models.JSONField(default=None, db_default=None, null=True),
        ),
        migrations.RemoveField(
            model_name="cellline",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="cellmarker",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="celltype",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="developmentalstage",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="disease",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="ethnicity",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="experimentalfactor",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="gene",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="organism",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="pathway",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="phenotype",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="protein",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="source",
            name="_previous_runs",
        ),
        migrations.RemoveField(
            model_name="tissue",
            name="_previous_runs",
        ),
    ]
